NAME
IWL::Accordion::Page - a page used in a accordion
INHERITANCE
IWL::Error -> IWL::Object -> IWL::Widget -> IWL::Container -> IWL::Accordion::Page
DESCRIPTION
The accordion page widget is a helper widget used by the IWL::Accordion
CONSTRUCTOR
IWL::Accordion::Page->new ([%ARGS])
Where %ARGS is an optional hash parameter with with key-values.
METHODS
- appendContent (OBJECT)
-
Appends the object to the page
Parameter: OBJECT - the IWL::Object to be appended
- prependContent (OBJECT)
-
Prepends the object to the page
Parameter: OBJECT - the IWL::Object to be prepended
- setTitle (TEXT)
-
Sets the text of the page title
Parameters: TEXT - the text of the page title
- getTitle
-
Returns the title of the page
- setSelected (BOOL)
-
Sets whether the page is the currently selected page
Parameters: BOOL - true if the page should be the currently selected one
- isSelected
-
Returns true if the page is the currently selected one
LICENCE AND COPYRIGHT
Copyright (c) 2006-2008 Viktor Kojouharov. All rights reserved.
This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself. See perldoc perlartistic.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
1 POD Error
The following errors were encountered while parsing the POD:
- Around line 175:
You forgot a '=back' before '=head1'